pub struct CompileOutput {
pub hir: Hir,
pub mir: MirContext,
pub conflicting_types: HashSet<Symbol>,
pub source_map: SourceMap,
}Expand description
The result of a successful compilation through the full pipeline.
Fields
hir: HirThe type-checked HIR.
mir: MirContextThe lowered MIR (after borrow checking).
conflicting_types: HashSet<Symbol>Types that appear in multiple modules with the same name (for C codegen disambiguation).
source_map: SourceMapThe source map used during compilation (for error reporting).